##
##  libconfig.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         libconfig
Summary:      Configuration Library
URL:          https://hyperrealm.github.io/libconfig/
Vendor:       HyperRealm
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Parsing
License:      LGPL
Version:      1.8.1
Release:      20250529

#   package options
%option       with_cxx  no

#   list of sources
Source0:      https://hyperrealm.github.io/libconfig/dist/libconfig-%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
%if "%{with_cxx}" == "yes"
BuildPreReq:  gcc, gcc::with_cxx = yes
%endif

%description
    Libconfig is a simple library for processing structured
    configuration files. This file format is more compact and more
    readable than XML. And unlike XML, it is type-aware, so it is not
    necessary to do string parsing in application code.

%track
    prog libconfig = {
        version   = %{version}
        url       = https://hyperrealm.github.io/libconfig/
        regex     = libconfig-(__VER__)\.tar\.gz
    }

%prep
    %setup -q

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
%if "%{with_cxx}" == "yes"
    CXX="%{l_cxx}" \
    CXXFLAGS="%{l_cxxflags -O}" \
%endif
    ./configure \
        --prefix=%{l_prefix} \
        --infodir=%{l_prefix}/info \
%if "%{with_cxx}" == "yes"
        --enable-cxx \
%else
        --disable-cxx \
%endif
        --disable-examples \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

